# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="lint.proto",
    package="lint",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\nlint.proto\x12\x04lint"\x1e\n\x0bLintRequest\x12\x0f\n\x07message\x18\x01 \x01(\t"\x1c\n\tLintReply\x12\x0f\n\x07message\x18\x01 \x01(\t2=\n\tLintProto\x12\x30\n\x08SendLint\x12\x11.lint.LintRequest\x1a\x0f.lint.LintReply"\x00\x62\x06proto3',
)


_LINTREQUEST = _descriptor.Descriptor(
    name="LintRequest",
    full_name="lint.LintRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="message",
            full_name="lint.LintRequest.message",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=20,
    serialized_end=50,
)


_LINTREPLY = _descriptor.Descriptor(
    name="LintReply",
    full_name="lint.LintReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="message",
            full_name="lint.LintReply.message",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=52,
    serialized_end=80,
)

DESCRIPTOR.message_types_by_name["LintRequest"] = _LINTREQUEST
DESCRIPTOR.message_types_by_name["LintReply"] = _LINTREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LintRequest = _reflection.GeneratedProtocolMessageType(
    "LintRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LINTREQUEST,
        "__module__": "lint_pb2"
        # @@protoc_insertion_point(class_scope:lint.LintRequest)
    },
)
_sym_db.RegisterMessage(LintRequest)

LintReply = _reflection.GeneratedProtocolMessageType(
    "LintReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _LINTREPLY,
        "__module__": "lint_pb2"
        # @@protoc_insertion_point(class_scope:lint.LintReply)
    },
)
_sym_db.RegisterMessage(LintReply)


_LINTPROTO = _descriptor.ServiceDescriptor(
    name="LintProto",
    full_name="lint.LintProto",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=82,
    serialized_end=143,
    methods=[
        _descriptor.MethodDescriptor(
            name="SendLint",
            full_name="lint.LintProto.SendLint",
            index=0,
            containing_service=None,
            input_type=_LINTREQUEST,
            output_type=_LINTREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_LINTPROTO)

DESCRIPTOR.services_by_name["LintProto"] = _LINTPROTO

# @@protoc_insertion_point(module_scope)
